==> ogre-next-2.3.3-1-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/class_ogre_1_1_planar_reflections.js <==
var class_ogre_1_1_planar_reflections =
[
    [ "TrackedRenderable", "struct_ogre_1_1_planar_reflections_1_1_tracked_renderable.html", "struct_ogre_1_1_planar_reflections_1_1_tracked_renderable" ],
    [ "CustomParameterBits", "class_ogre_1_1_planar_reflections.html#aef23063b9860dc2511f94643d68a5144", [
      [ "UseActiveActor", "class_ogre_1_1_planar_reflections.html#aef23063b9860dc2511f94643d68a5144a8e1d29960d0fddea25d2490406ce8147", null ],
      [ "FlushPending", "class_ogre_1_1_planar_reflections.html#aef23063b9860dc2511f94643d68a5144aa08ad430b01d82bb98e6b001f4d316ca", null ],
      [ "InactiveActor", "class_ogre_1_1_planar_reflections.html#aef23063b9860dc2511f94643d68a5144a5ed119fb61ead1864d8eab0da69f2541", null ]
    ] ],
    [ "PlanarReflections", "class_ogre_1_1_planar_reflections.html#a97c05aeec8d1c4307a78d98e45a5cbc1", null ],
    [ "~PlanarReflections", "class_ogre_1_1_planar_reflections.html#a263fc6936942eb8fd5162a5c6d3566dd", null ],
    [ "_isUpdatingRenderablesHlms", "class_ogre_1_1_planar_reflections.html#aa9c304509b595687e7af5ae0d513973a", null ],
    [ "_notifyRenderableFlushedHlmsDatablock", "class_ogre_1_1_planar_reflections.html#ab3c42759975878d5744bfd2bebc313a4", null ],
    [ "addActor", "class_ogre_1_1_planar_reflections.html#ad67ceb649027af939376cbd4f3b62f9f", null ],
    [ "addRenderable", "class_ogre_1_1_planar_reflections.html#a50aeb6eec3120373b6d5316909128235", null ],
    [ "beginFrame", "class_ogre_1_1_planar_reflections.html#ae4592b5013e603bd0343181395bfcc81", null ],
    [ "cameraMatches", "class_ogre_1_1_planar_reflections.html#a08baa1e192558155350dc4cae0779c39", null ],
    [ "destroyActor", "class_ogre_1_1_planar_reflections.html#a44003f3183c9912fc8bd0dbe08130dc4", null ],
    [ "destroyAllActors", "class_ogre_1_1_planar_reflections.html#a893c5a907aa1a9137733da536fd81c72", null ],
    [ "fillConstBufferData", "class_ogre_1_1_planar_reflections.html#ab6b4e4365e298e1964114c9f88affca4", null ],
    [ "getConstBufferSize", "class_ogre_1_1_planar_reflections.html#a6b97bf4ca49cb975146865babaebd38c", null ],
    [ "getMaxActiveActors", "class_ogre_1_1_planar_reflections.html#a216041e0cac9583d98a4023051981296", null ],
    [ "getMaxNumMipmaps", "class_ogre_1_1_planar_reflections.html#ae8585442d3a502ca1b714b399708e8c3", null ],
    [ "getTexture", "class_ogre_1_1_planar_reflections.html#a3e77bc1097363a43c816bb61b4c4def8", null ],
    [ "hasActiveActor", "class_ogre_1_1_planar_reflections.html#ad57f5c1c97d776977f0ac26dae2cb023", null ],
    [ "hasFlushPending", "class_ogre_1_1_planar_reflections.html#ae093845778350033e17071693735d09b", null ],
    [ "hasPlanarReflections", "class_ogre_1_1_planar_reflections.html#a115bdf1bc345cec24869a367e2d14fcc", null ],
    [ "releaseReservation", "class_ogre_1_1_planar_reflections.html#a1b6e9c4ba6c9805abc9c530848857d3d", null ],
    [ "removeRenderable", "class_ogre_1_1_planar_reflections.html#ab4446a0ebad33a188b5768db4c2ea813", null ],
    [ "reserve", "class_ogre_1_1_planar_reflections.html#a348398b976bbd1bc920a1949cb6daa0e", null ],
    [ "setMaxActiveActors", "class_ogre_1_1_planar_reflections.html#a3a58842a57fece487fd4601d1845f8f2", null ],
    [ "setMaxDistance", "class_ogre_1_1_planar_reflections.html#a2771ce1222f8acb51cda2d9c84274d85", null ],
    [ "update", "class_ogre_1_1_planar_reflections.html#a7c96969df4853b0d5c1e3f0c6adae41a", null ]
];

==> ogre-next-3.0.0-2-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/class_ogre_1_1_planar_reflections.js <==
var class_ogre_1_1_planar_reflections =
[
    [ "TrackedRenderable", "struct_ogre_1_1_planar_reflections_1_1_tracked_renderable.html", "struct_ogre_1_1_planar_reflections_1_1_tracked_renderable" ],
    [ "CustomParameterBits", "class_ogre_1_1_planar_reflections.html#aef23063b9860dc2511f94643d68a5144", [
      [ "UseActiveActor", "class_ogre_1_1_planar_reflections.html#aef23063b9860dc2511f94643d68a5144a8e1d29960d0fddea25d2490406ce8147", null ],
      [ "FlushPending", "class_ogre_1_1_planar_reflections.html#aef23063b9860dc2511f94643d68a5144aa08ad430b01d82bb98e6b001f4d316ca", null ],
      [ "InactiveActor", "class_ogre_1_1_planar_reflections.html#aef23063b9860dc2511f94643d68a5144a5ed119fb61ead1864d8eab0da69f2541", null ]
    ] ],
    [ "PlanarReflections", "class_ogre_1_1_planar_reflections.html#a97c05aeec8d1c4307a78d98e45a5cbc1", null ],
    [ "~PlanarReflections", "class_ogre_1_1_planar_reflections.html#a263fc6936942eb8fd5162a5c6d3566dd", null ],
    [ "_isUpdatingRenderablesHlms", "class_ogre_1_1_planar_reflections.html#ab3e9deeab20cecd7a726be023381aab6", null ],
    [ "_notifyRenderableFlushedHlmsDatablock", "class_ogre_1_1_planar_reflections.html#ab3c42759975878d5744bfd2bebc313a4", null ],
    [ "addActor", "class_ogre_1_1_planar_reflections.html#ad67ceb649027af939376cbd4f3b62f9f", null ],
    [ "addRenderable", "class_ogre_1_1_planar_reflections.html#a50aeb6eec3120373b6d5316909128235", null ],
    [ "beginFrame", "class_ogre_1_1_planar_reflections.html#a3dd439594c476fb85b3a930a81b2864b", null ],
    [ "cameraMatches", "class_ogre_1_1_planar_reflections.html#a08baa1e192558155350dc4cae0779c39", null ],
    [ "countActiveActors", "class_ogre_1_1_planar_reflections.html#a0765f86abacd811fdea0dc2941efb5cd", null ],
    [ "destroyActor", "class_ogre_1_1_planar_reflections.html#a44003f3183c9912fc8bd0dbe08130dc4", null ],
    [ "destroyAllActors", "class_ogre_1_1_planar_reflections.html#a026bf3208a69c61edf6ceb2c5a93dbc1", null ],
    [ "fillConstBufferData", "class_ogre_1_1_planar_reflections.html#a583a80a19f90f0922c77e7060701e1d5", null ],
    [ "getConstBufferSize", "class_ogre_1_1_planar_reflections.html#a062e2390a6435337c30cf651a496732d", null ],
    [ "getMaxActiveActors", "class_ogre_1_1_planar_reflections.html#ae67e1c9b55f6297e9c138e628446ee7a", null ],
    [ "getMaxNumMipmaps", "class_ogre_1_1_planar_reflections.html#ae8585442d3a502ca1b714b399708e8c3", null ],
    [ "getTexture", "class_ogre_1_1_planar_reflections.html#a3e77bc1097363a43c816bb61b4c4def8", null ],
    [ "hasActiveActor", "class_ogre_1_1_planar_reflections.html#ad57f5c1c97d776977f0ac26dae2cb023", null ],
    [ "hasFlushPending", "class_ogre_1_1_planar_reflections.html#ae093845778350033e17071693735d09b", null ],
    [ "hasPlanarReflections", "class_ogre_1_1_planar_reflections.html#a115bdf1bc345cec24869a367e2d14fcc", null ],
    [ "releaseReservation", "class_ogre_1_1_planar_reflections.html#a1b6e9c4ba6c9805abc9c530848857d3d", null ],
    [ "removeRenderable", "class_ogre_1_1_planar_reflections.html#ab4446a0ebad33a188b5768db4c2ea813", null ],
    [ "reserve", "class_ogre_1_1_planar_reflections.html#a348398b976bbd1bc920a1949cb6daa0e", null ],
    [ "setMaxActiveActors", "class_ogre_1_1_planar_reflections.html#a3a58842a57fece487fd4601d1845f8f2", null ],
    [ "setMaxDistance", "class_ogre_1_1_planar_reflections.html#a2771ce1222f8acb51cda2d9c84274d85", null ],
    [ "update", "class_ogre_1_1_planar_reflections.html#a7c96969df4853b0d5c1e3f0c6adae41a", null ]
];
